/* DeleteECSCtrlZ.Cmd: Delete stupid eCS CtrlZ

    Copyright (c) 2002 Steven Levine and Associates, Inc.
    All rights reserved.

    $TLIB$: $ &(#) %n - Ver %v, %f $
    TLIB: $ $

    Revisions	05 Jan 02 SHL - Release

*/

signal on Error
signal on FAILURE name Error
signal on Halt
signal on NOTREADY name Error
signal on NOVALUE name Error
signal on SYNTAX name Error

call Initialize

Gbl.Version = '0.2'

Main:

  parse arg szArgs
  call ScanArgs szArgs
  drop szArgs

  do iArg = 1 to Gbl.aArgs.0

    szInFile = Gbl.aArgs.iArg

    say 'Processing' szInFile

    if IsWild(szInFile) \= '' then
      call Fatal 'wildcards not allowed'

    if IsDir(szInFile) \= '' then
      call Fatal szInFile 'is a directory'

    if IsFile(szInFile) == '' then
      call Fatal szInFile 'not found'

    drop szCondition
    call on NOTREADY name CatchError	/* Avoid death */
    rc = stream(szInFile, 'C', 'OPEN READ')
    signal on NOTREADY name Error

    if rc \= 'READY:' then
      call Fatal 'Can not open:' rc

    cWant = chars(szInFile)

    szBuf = charin(szInFile, 1, cWant)

    cRead = length(szBuf)

    if cWant \= cRead then
      call Fatal 'Wanted' cWant 'bytes - Read' cRead

    say 'Read' cRead 'bytes'

    call stream szInFile, 'C', 'CLOSE'

    ch = left(szBuf, 1)

    if ch \= x2c('1a') then
      call Fatal 'Expected Ctrl-Z as first character'

    call SysFileDelete(szInFile)

    call charout szInFile, substr(szBuf, 2)

    call stream szInFile, 'C', 'CLOSE'

    say 'Wrote' cRead - 1 'bytes'

  end /* iArg */

  exit

/* end main */

/*=== Initialize(): Intialize globals ===*/

Initialize: procedure expose Gbl.

  call LoadFuncs

  /* Set:
      Gbl.szCmdName
      Gbl.szTmpDir - default = TMP or TEMP, trailing \ forced
  */

  parse source . . sz
  sz = filespec('N', sz)
  c = pos('.', sz)
  if c > 1 then
    sz = left(sz, c - 1)
  Gbl.szCmdName = ToLower(sz)

  sz = value('TMP',,'OS2ENVIRONMENT')
  if sz \= '' & right(sz, 1) \= ':' & right(sz, 1) \= '\' then
    sz = sz'\'
  Gbl.szTmpDir = sz

  return

/* end Initialize */

/*=== IsDir(DirName): return normalized directory name with trailing \ or empty string ===*/

IsDir: procedure expose Gbl.

  parse arg szArg

  if szArg == '' then
    szDir = ''
  else do
    if IsDrvRdy(szArg) then do
      sz = directory()
      szDir = directory(szArg)
      call directory(sz)
      if szDir \== '' & right(szDir, 1) \= '\' then
	szDir = szDir'\'
    end /* if */
  end /* if */

  if symbol('Gbl.Opt.fDebug') = 'VAR' then if Gbl.Opt.fDebug then
    say 'IsDir('szArg') returns' ''''szDir''''

  return szDir

/* end IsDir */

/*=== IsDrvRdy(): return 1 if ready ===*/

IsDrvRdy: procedure expose Gbl.

  szArg = arg(1)

  if length(szArg) >= 2 & substr(szArg, 2, 1) = ':' then do
    sz = translate(substr(szArg, 1, 1))
    /* If not a drive letter, say not ready */
    if sz >= 'A' & sz <= 'Z' then do
      sz = SysDriveInfo(sz)
      f = sz \== ''			/* Ready if not blank */
    end
    else
      f = 0				/* Bad drive spec */
  end
  else
    f = 1				/* Ready if no drive spec */

  if symbol('Gbl.Opt.fDebug') = 'VAR' then if Gbl.Opt.fDebug then
    say 'IsDrvRdy('szArg') returns' f

  return f

/* end IsDrvRdy */

/*=== IsFile(szFile): return normalized file name or empty string ===*/

IsFile: procedure expose Gbl.

  parse arg szArg

  if szArg == '' then
    szFile = ''
  else do
    /* Assume caller knows if arg contains wildcards wildcards */
    call SysFileTree szArg, 'aFiles', 'F'
    if aFiles.0 = 0 then
      szFile = ''
    else do
      parse value aFiles.1 with . . . szAttrib szFile
      szFile = strip(szFile)
    end /* Do */
  end /* Do */

  if symbol('Gbl.Opt.fDebug') = 'VAR' then if Gbl.Opt.fDebug then
    say 'IsFile('szArg') returns' ''''szFile''''

  return szFile

/* end IsFile */

/*=== IsWild(pathname): return wildcard character or empty string ===*/

IsWild: procedure

  parse arg sz
  i = verify(sz,'*?', 'M')
  if i \= 0 then
    sz = substr(sz, i, 1)
  else
    sz = ''

  return sz

/* end IsWild */

/*=== ScanArgs(argLine): scan command line arguments and switches ===*/

ScanArgs: procedure expose Gbl.

  /* Evaluate arguments - override
     Return Gbl.Opt. and Gbl.aArgs. etc.
  */

  parse arg szRest
  szRest = strip(szRest)

  if szRest == '' then
    call UsageHelp

  /* Set defaults */
  Gbl.Opt.fDebug = 0
  Gbl.Opt.fVerbose = 0			/* Verbose messages */
  Gbl.aArgs.0 = 0			/* Init arg count */

  /* Prepare scanner */
  szSwCtl = 'f'				/* Switches that take args */
  szArg = ''				/* Current argument string */
  szSw = ''				/* Current switch list */
  fSwEnd = 0				/* End of switches */

  do while szRest \== '' | szArg \== '' | szSw \== ''

    if szArg == '' then do
      /* Buffer empty, refill */
      szQ = left(szRest, 1)		/* Remember quote */
      if \ verify(szQ,'''"', 'M') then do
	parse var szRest szArg szRest	/* Not quoted */
      end
      else do
	/* Arg is quoted */
	szArg = ''
	do forever
	  /* Parse dropping quotes */
	  parse var szRest (szQ)szArg1(szQ) szRest
	  szArg = szArg || szArg1
		/* Check for escaped quote within quoted string (i.e. "" or '') */
	  if left(szRest, 1) \== szQ then
	    leave			/* No, done */
	  szArg = szArg || szQ		/* Append quote */
	  parse var szRest (szQ) szRest
	end /* do */
      end /* if quoted */
    end

    /* If switch buffer empty, refill */
    if szSw == '' then do
      if left(szArg, 1) == '-' then do
	if fSwEnd then
	  call Usage 'switch '''szArg''' unexpected'
	else if szArg == '--' then
	  fSwEnd = 1
	else
	  szSw = substr(szArg, 2)
	parse var szRest szArg szRest
      end
    end

    /* If switch in progress */
    if szSw \== '' then do
      sz = left(szSw, 1)		/* Next switch */
      szSw = substr(szSw, 2)		/* Drop from pending */
      if Gbl.Opt.fDebug then
	say '* Switch' sz
      /* Check switch requires argument */
      if pos(sz, szSwCtl) \= 0 then do
	if szSw \== '' then do
	  szOpt = szSw
	  szSw = ''
	end
	else if szArg \== '' & left(szArg, 1) \= '-' then do
	  szOpt = szArg
	  parse var szRest szArg szRest
	end
	else
	  call Usage 'Switch' sz 'requires argument'
	if Gbl.Opt.fDebug then
	  say '* Opt' szOpt
      end
      select
      when sz == 'd' then
	Gbl.Opt.fDebug = 1
      when sz == 'h' | sz == '?' then
	call UsageHelp
      when sz == 'V' then do
	say Gbl.szCmdName Gbl.Version
	exit
      end
      otherwise
	call Usage 'switch '''sz''' unexpected'
      end /* select */
    end /* if switch */

    /* If arg */
    else if szArg \== '' then do
      fSwEnd = 1			/* No more switches */
      if Gbl.Opt.fDebug then
	say '* Arg' szArg
      /* Got non switch arg */
      i = Gbl.aArgs.0 + 1
      Gbl.aArgs.i = szArg
      Gbl.aArgs.0 = i
      szArg = ''
    end

  end /* while szRest */

  if Gbl.aArgs.0 = 0 then
    call UsageHelp

  return

/* end ScanArgs */

/*=== Usage(szMsg): Report Usage Error... ===*/

Usage:
  parse arg szMsg
  say szMsg
  say 'Usage:' Gbl.szCmdName '[-h] [-V] filename...'
  exit 255

/* end Usage */

/*=== UsageHelp(): Display usage help ===*/

UsageHelp:

  say
  say 'Usage:' Gbl.szCmdName '[-h] [-V] filename...'
  say
  say ' -h        Show this message'
  say ' -V        Show version'
  say
  say ' filename  File to edit'

  exit 255

/* end UsageHelp */

/*========================================================================== */
/*=== Standard functions - Delete unused.  Move modified above this mark === */
/*========================================================================== */

/*=== Error(): Trap ERROR, FAILURE etc. conditions ===*/

Error:

  /*=== Returns szCondition or Exits ===*/

  say
  parse source . . szThisCmd
  say condition('C') 'signaled at' SIGL 'of' szThisCmd
  drop szThisCmd
  say 'Source =' sourceline(SIGL)
  call SysSleep 2
  if condition('I') == 'CALL' then do
    szCondition = condition('C')
    say 'Returning'
    return
  end
  else do
    trace '?A'
    say 'Exiting'
    call SysSleep 2
    exit 255
  end

/* end Error */

/*=== Fatal(message): Report fatal error and exit ===*/

Fatal:

  parse arg szMsg

  say
  say Gbl.szCmdName':' szMsg

  call Beep 200, 300

  exit 254

/* end Fatal */

/*=== Halt(): Trap HALT condition ===*/

Halt:

  /*=== Returns szCondition or Exits ===*/

  say
  parse source . . szThisCmd
  say condition('C') 'signaled at' SIGL 'of' szThisCmd
  drop szThisCmd
  say 'Source = ' sourceline(SIGL)
  call SysSleep 2
  if condition('I') == 'CALL' then do
    szCondition = condition('C')
    say 'Returning'
    return
  end
  else do
   say 'Exiting'
   exit
  end

/* end Halt */

/*=== LoadFuncs(): Load fuctions ===*/

LoadFuncs:

  /* Add all Rexx functions */
  if RxFuncQuery('SysLoadFuncs') then do
    call RxFuncAdd 'SysLoadFuncs', 'REXXUTIL', 'SysLoadFuncs'
    if RESULT then do
      say 'Cannot load SysLoadFuncs'
      exit
    end
    call SysLoadFuncs
  end /* end do */

  return

/* end LoadFuncs */

/*=== ToLower(sz): Convert to lower case ===*/

ToLower: procedure

  parse arg sz

  return translate(sz, xrange('a', 'z'), xrange('A', 'Z'))

/* end ToLower */

/* The end */
